@@ -50,6 +50,12 @@ ConceptLattice <- R6::R6Class(
       private$pr_extents <- extents
       private$pr_intents <- intents
 
+      if (!capabilities()["long.double"]) {
+
+        private$can_plot <- FALSE
+
+      }
+
       # Create the SparseConcepts
       if (!is.null(extents)) {
 
@@ -60,7 +66,6 @@ ConceptLattice <- R6::R6Class(
           attributes = attributes)
 
         private$I <- I
-        # private$subconcept_matrix <- .subset(extents)
 
       }
 
@@ -138,9 +143,6 @@ ConceptLattice <- R6::R6Class(
     #' @return If \code{to_latex} is \code{FALSE}, it returns nothing, just plots the graph of the concept lattice. Otherwise, this function returns the \code{LaTeX} code to reproduce the concept lattice.
     #' @export
     #'
-    #' @importFrom hasseDiagram hasse
-    #' @importFrom stringr str_replace_all fixed
-    #' @importFrom tikzDevice tikz
     plot = function(object_names = TRUE,
                     to_latex = FALSE,
                     ...) {
@@ -151,14 +153,22 @@ ConceptLattice <- R6::R6Class(
 
       }
 
+      if (!private$can_plot) {
+
+        warning("The R system has not the needed capabilities to plot.",
+                call. = FALSE)
+        return(invisible(FALSE))
+
+      }
+
       if (to_latex) {
 
         if (object_names) {
 
           labels <- sapply(private$concepts,
                            function(l) l$to_latex(print = FALSE)) %>%
-            str_replace_all(pattern = "\n",
-                            replacement = "")
+            stringr::str_replace_all(pattern = "\n",
+                                     replacement = "")
 
         } else {
 
@@ -171,8 +181,8 @@ ConceptLattice <- R6::R6Class(
         }
 
         labels <- labels %>%
-          str_replace_all(pattern = fixed(" "),
-                          replacement = "\\,")
+          stringr::str_replace_all(pattern = stringr::fixed(" "),
+                                   replacement = "\\,")
 
       } else {
 
@@ -265,7 +275,7 @@ ConceptLattice <- R6::R6Class(
         if ("pointsize" %in% names(dots)) {
 
           options("tikzDocumentDeclaration" = paste0("\\documentclass[", dots$pointsize,
-                                                    "pt]{article}\n"))
+                                                     "pt]{article}\n"))
 
         }
 
@@ -276,13 +286,13 @@ ConceptLattice <- R6::R6Class(
 
         args[names(dots)] <- dots[names(dots)]
 
-        do.call(tikz, args = args)
+        do.call(tikzDevice::tikz, args = args)
 
       }
 
-      hasse(data = as.matrix(t(private$subconcept_matrix)),
-            labels = labels,
-            parameters = list(arrows = "backward"))
+      hasseDiagram::hasse(data = Matrix::as.matrix(Matrix::t(private$subconcept_matrix)),
+                          labels = labels,
+                          parameters = list(arrows = "backward"))
 
       if (to_latex) {
 
@@ -467,7 +477,6 @@ ConceptLattice <- R6::R6Class(
     #'
     #' @export
     #'
-    #' @importFrom Matrix colSums
     join_irreducibles = function() {
 
       if ((self$size() > 0) & (is.null(private$subconcept_matrix))) {
@@ -482,7 +491,7 @@ ConceptLattice <- R6::R6Class(
 
       }
 
-      idx <- which(colSums(private$reduced_matrix) == 1)
+      idx <- which(Matrix::colSums(private$reduced_matrix) == 1)
       self[idx]
 
     },
@@ -495,7 +504,6 @@ ConceptLattice <- R6::R6Class(
     #'
     #' @export
     #'
-    #' @importFrom Matrix colSums
     meet_irreducibles = function() {
 
       if ((self$size() > 0) & (is.null(private$subconcept_matrix))) {
@@ -504,9 +512,9 @@ ConceptLattice <- R6::R6Class(
 
       }
 
-      M <- .reduce_transitivity(t(private$subconcept_matrix))
+      M <- .reduce_transitivity(Matrix::t(private$subconcept_matrix))
 
-      idx <- which(colSums(M) == 1)
+      idx <- which(Matrix::colSums(M) == 1)
       self[idx]
 
     },
@@ -520,7 +528,6 @@ ConceptLattice <- R6::R6Class(
     #'
     #' @export
     #'
-    #' @importFrom Matrix rowSums
     decompose = function(C) {
 
       irreducible <- self$meet_irreducibles()
@@ -533,13 +540,13 @@ ConceptLattice <- R6::R6Class(
 
                      if (r$get_intent()$cardinal() == 0) return(r)
 
-                     id <- which(.subset(irr_intents,
-                                         r$get_intent()$get_vector()))
+                     id <- Matrix::which(.subset(irr_intents,
+                                                 r$get_intent()$get_vector()))
 
                      if (length(id) > 1) {
 
                        MM <- .subset(irr_intents[, id])
-                       id <- id[rowSums(MM) == 1]
+                       id <- id[Matrix::rowSums(MM) == 1]
 
                      }
                      foo <- irreducible[id]
@@ -626,8 +633,8 @@ ConceptLattice <- R6::R6Class(
       }
 
       # Get the index of all subconcepts
-      M <- t(private$subconcept_matrix)[idx, ]
-      candidates <- which(M > 0)
+      M <- Matrix::t(private$subconcept_matrix)[idx, ]
+      candidates <- Matrix::which(M > 0)
 
       self[candidates]
 
@@ -721,7 +728,6 @@ ConceptLattice <- R6::R6Class(
     #' Get support of each concept
     #'
     #' @return A vector with the support of each concept.
-    #' @importFrom Matrix rowMeans
     #' @export
     support = function() {
 
@@ -736,7 +742,7 @@ ConceptLattice <- R6::R6Class(
 
       subsets <- .subset(private$pr_intents, my_I)
 
-      private$concept_support <- rowMeans(subsets)
+      private$concept_support <- Matrix::rowMeans(subsets)
 
       return(private$concept_support)
 
@@ -756,6 +762,8 @@ ConceptLattice <- R6::R6Class(
     I = NULL,
     concept_support = NULL,
 
+    can_plot = TRUE,
+
     concept_list_to_indices = function(concept_list) {
 
       extents <- lapply(concept_list,
@@ -766,7 +774,7 @@ ConceptLattice <- R6::R6Class(
       indices <- .equal_sets(x = extents,
                              y = private$pr_extents)
 
-      indices <- arrayInd(which(indices),
+      indices <- arrayInd(Matrix::which(indices),
                           .dim = dim(indices))[, 2]
 
       return(indices)
