@@ -1,8 +1,6 @@
-#' @importFrom stringr str_flatten
-#' @importFrom Matrix which
 .set_to_string <- function(S, attributes) {
 
-  idx <- which(S > 0)
+  idx <- Matrix::which(S > 0)
 
   if (length(idx) > 0) {
 
@@ -10,7 +8,7 @@
     att <- attributes[idx]
 
     tmp <- paste0("{",
-                  str_flatten(paste0(att, " [", A, "]"),
+                  stringr::str_flatten(paste0(att, " [", A, "]"),
                               collapse = ", "), "}")
 
     gsub(pattern = "( \\[1\\])", replacement = "", x = tmp)
